
# Slot: todos


Outstanding issue that needs resolution

URI: [linkml:todos](https://w3id.org/linkml/todos)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..\*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * anonymous_class_expression
 * anonymous_expression
 * anonymous_slot_expression
 * class_definition
 * class_rule
 * common_metadata
 * definition
 * [Element](Element.md)
 * enum_definition
 * permissible_value
 * schema_definition
 * slot_definition
 * subset_definition
 * type_definition
 * unique_key
